/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import nl.cloudfarming.client.model.CommonModelService;
import nl.cloudfarming.client.model.Operation;
import nl.cloudfarming.client.model.Remedy;
import nl.cloudfarming.client.model.RemedyAppliance;
import nl.cloudfarming.client.model.crop.Crop;
import nl.cloudfarming.client.stock.StockService;
import org.openide.explorer.ExplorerManager;
import org.openide.util.lookup.ServiceProvider;

/**
 * Class for common CropProtection service methods Always use serviceProvider to
 * instantiate
 *
 * @author Merijn Zengers
 */
@ServiceProvider(service = StockService.class)
public class StockServiceImpl extends CommonModelService implements StockService {
    
    private final List<Remedy> remedies = Collections.synchronizedList(new ArrayList<Remedy>());

    @Override
    protected ExplorerManager initExplorer() {
        return new ExplorerManager();
    }


    @Override
    public RemedyAppliance createAppliance(Remedy remedy, Operation operation) {
        RemedyAppliance appliance = new RemedyAppliance();
        appliance.setOperation(operation);
        appliance.setRemedy(remedy);
        return appliance;
    }

    @Override
    public List<Remedy> getAllRemedies(Crop crop) {
        //FIXME filter remedies for crop.
        return remedies;
    }
    
    public void addRemedy(Remedy remedy){
        remedies.add(remedy);
    }

}
