/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a copy
 * of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.scheduler;

import java.util.Collection;
import java.util.TimerTask;
import nl.cloudfarming.client.model.Remedy;
import nl.cloudfarming.client.stock.RemedyProvider;
import nl.cloudfarming.client.stock.StockService;
import nl.cloudfarming.client.stock.impl.StockServiceImpl;
import org.openide.util.Lookup;

/**
 * Worker class to update the persisted CropProtection or create new ones from
 * data acquired from the web services
 *
 * @author Merijn Zengers
 */
public class WebServiceUpdater extends TimerTask {

    public WebServiceUpdater(){
    }
    /**
     * Will lookup all the the ServiceProviders of type CropProtectionService.class
     * Will get all the cropProtections they provide through getCropProtection()
     * Will create or update existing CropProtecton with new values
     */
    @Override
    public void run() {
        StockServiceImpl stockService = Lookup.getDefault().lookup(StockServiceImpl.class);
        
        Collection<? extends RemedyProvider> cropProtectionServices = Lookup.getDefault().lookupAll(RemedyProvider.class);
        for (RemedyProvider service : cropProtectionServices) {
            for (Remedy remedy : service.getRemedies()) {
                stockService.addRemedy(remedy);
            }
        }
    }

    
    
    
}
